# PaperCut XML WebServices API

[![](https://img.shields.io/pypi/v/papercut_xml_webservices_api.svg)](https://pypi.python.org/pypi/papercut_xml_webservices_api)
-   Free software: MIT license
-   Not affiliated with PaperCut Software
-   [Documentation](https://github.com/safehome-jdev/PaperCutSoftware/blob/main/api/papercut_xml_webservices_api/README.md)
-   [PaperCut API Docs](https://www.papercut.com/help/manuals/ng-mf/common/tools-web-services/)

# Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage) project template.